@@ -379,9 +379,12 @@ function()
 	embed_id= embed_id[embed_id.length-1];
     }
 
+    var p = this.get_first_element_by_class("flash-player");
+    p = p ? p : this.get_first_element_by_class("html5-player");
+
+
     if (!width || !height)
     {
-	var p = document.getElementById("watch-player");
 	height = p ? p.clientHeight : null;
 	width  = p ? p.clientWidth : null;
     }
@@ -433,7 +436,7 @@ function()
 	linterna_magica_id =
 	    this.mark_flash_object("extracted-from-script");
 
-	object_data.parent = document.getElementById("watch-player");
+	object_data.parent =  p;
     }
 
     object_data.linterna_magica_id = linterna_magica_id;
@@ -661,3 +664,41 @@ function(object_data)
 
     return false;
 }
+
+// Fixes the overlapping of the HD links list in YouTube's new design
+// See bug #37881
+// http://savannah.nongnu.org/bugs/?37881
+LinternaMagica.prototype.sites["youtube.com"].post_show_hd_links_list =
+function()
+{
+    var play_list= document.getElementById("watch7-playlist-tray-container");
+    if (play_list)
+    {
+	play_list.style.setProperty("display", "none", "important");
+    }
+
+    var side_bar= document.getElementById("watch7-sidebar");
+    if (side_bar)
+    {
+	side_bar.style.setProperty("display", "none", "important");
+    }
+}
+
+// Fixes the overlapping of the HD links list in YouTube's new design
+// See bug #37881
+// http://savannah.nongnu.org/bugs/?37881
+LinternaMagica.prototype.sites["youtube.com"].post_hide_hd_links_list =
+function()
+{
+    var play_list= document.getElementById("watch7-playlist-tray-container");
+    if (play_list)
+    {
+	play_list.style.removeProperty("display");
+    }
+
+    var side_bar= document.getElementById("watch7-sidebar");
+    if (side_bar)
+    {
+	side_bar.style.removeProperty("display");
+    }
+}
